@@ -14,4 +14,7 @@ pub use self::cache::Cache;
 pub use self::cache::Store;
 pub use self::headers::Headers;
 pub use self::value::Value;
-pub use self::untils::tool::Tool;
\ No newline at end of file
+pub use self::untils::tool::Tool;
+pub use dbfile::DBfile;
+pub use dbfile_derive::{DBfile, dbnote};
+
